## Install Pyneval
If you are using conda, use this command:

    conda install -c csdllab -c conda-forge pyneval

For **windows** user, package rtree need to be specified as 0.9.3

    conda install -c csdllab -c conda-forge pyneval rtree==0.9.3

Otherwise, use pip:

    pip install pyneval

For developer, source code can be found [here](https://github.com/CSDLLab/PyNeval)
